@@ -6,7 +6,8 @@
     import reflect.runtime.{universe => ru}
     ru.typeOf[@{type}].members.map(_.toString).toSet.filter(_.startsWith("method ")).map(_.substring(7)).filter(!_.startsWith("$")).toArray
   '
-  snippet <- sub("@\\{type\\}",x[['type']],snippet)
-  methods <- scalaInvoke(x[['details']], snippet, list())
+  env <- attr(x,"rscalaReferenceEnvironment")
+  snippet <- sub("@\\{type\\}",env[['type']],snippet)
+  methods <- scalaInvoke(env[['details']], snippet, list())
   grep(pattern, methods, value=TRUE)
 }
