@@ -14,23 +14,35 @@ toString.rscalaBridge <- function(x, ...) {
 #' @export
 #' 
 print.rscalaReference <- function(x, ...) {
+  env <- attr(x,"rscalaReferenceEnvironment")
+  if ( exists("original",envir=env) ) {
+    func <- get("original",envir=env)
+    if ( ! is.null(func) ) print(func)
+  }
   cat(toString(x, ...),"\n",sep="")
 }
 
 #' @export
 #
 toString.rscalaReference <- function(x, ...) {
-  paste0("rscala reference of type ",x[["type"]])
+  env <- attr(x,"rscalaReferenceEnvironment")
+  paste0("rscala reference of type ",env[["type"]])
 }
 
 #' @export
 #' 
-print.rscalaFunction <- function(x, ...) {
+print.rscalaSub <- function(x, ...) {
   cat(toString(x, ...),"\n",sep="")
 }
 
 #' @export
 #
-toString.rscalaFunction <- function(x, ...) {
-  "rscala function"
+toString.rscalaSub <- function(x, ...) {
+  "rscala stub"
+}
+
+#' @export
+#' 
+print.rscalaType <- function(x, ...) {
+  print(unclass(x), ...)
 }
